==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/kitchen/dialogs_fr.lua <==

dialogId("kuch-m-objev0", "font_small", "Oh my, this is a nice kitchen.")
dialogStr("Hé bien, c'est une chouette cuisine.")


dialogId("kuch-m-objev1", "font_small", "Yeah, we discovered the ship kitchen.")
dialogStr("Ouais, nous avons découvert la cuisine du vaisseau.")


dialogId("kuch-m-objev2", "font_small", "Darned kitchen.")
dialogStr("Sacrée cuisine.")


dialogId("kuch-m-objev3", "font_small", "And now we are in the captain Silver`s kitchen.")
dialogStr("Et maintenant nous sommes dans la cuisine du capitaine Silver.")


dialogId("kuch-v-varil", "font_big", "I don`t think he was a cook himself.")
dialogStr("Je ne pense pas qu'il cuisinait lui-même.")


dialogId("kuch-v-problem", "font_big", "But this is not our problem.")
dialogStr("Mais ce n'est pas notre problème.")


dialogId("kuch-m-noproblem", "font_small", "There are not many problems here. I can swim out at once.")
dialogStr("Il n'y a pas de problème ici. Je peux nager vers la sortie.")


dialogId("kuch-v-podivej", "font_big", "But just have a look at me.")
dialogStr("Mais regarde moi un peu.")


dialogId("kuch-v-stolky0", "font_big", "I can`t understand how these serving tables got there.")
dialogStr("Je ne comprends pas comment ces tables sont arrivées là.")


dialogId("kuch-v-stolky1", "font_big", "These tables are in the way.")
dialogStr("Ces tables bloquent le chemin.")


dialogId("kuch-v-stolky2", "font_big", "This little chamber gives me the creeps.")
dialogStr("Cette petit pièce me donne la frousse.")


dialogId("kuch-v-odsud0", "font_big", "I can`t get out of here!")
dialogStr("Je ne peux pas sortir d'ici !")


dialogId("kuch-m-premyslim0", "font_small", "I`m just thinking how to help you.")
dialogStr("Je réfléchis simplement à comment t'aider.")


dialogId("kuch-v-odsud1", "font_big", "Help me somehow!")
dialogStr("Aide moi à tout prix !")


dialogId("kuch-m-premyslim1", "font_small", "I am thinking...")
dialogStr("Je réfléchis...")


dialogId("kuch-m-premyslim2", "font_small", "I am on my way.")
dialogStr("J'arrive.")


dialogId("kuch-m-hrnec0", "font_small", "Yuck, there is something left in this pot!")
dialogStr("Beurk, il reste quelque chose dans ce pot !")


dialogId("kuch-m-hrnec1", "font_small", "This pot wasn`t even washed up.")
dialogStr("Ce pot n'a jamais été lavé.")


dialogId("kuch-m-hrnec2", "font_small", "Nobody washes the dishes here.")
dialogStr("Personne ne fait la vaisselle ici.")


dialogId("kuch-v-kreslo0", "font_big", "If there was no chair, it would save us a lot of work.")
dialogStr("S'il n'y avait pas de fauteuil, nous aurions beaucoup moins de travail.")


dialogId("kuch-v-ja", "font_big", "Especially myself.")
dialogStr("Surtout moi.")


dialogId("kuch-m-kreslo0", "font_small", "What is a chair doing in a kitchen?")
dialogStr("Que fait un fauteuil dans une cuisine ?")


dialogId("kuch-v-kreslo1", "font_big", "There should be no chairs in the kitchen.")
dialogStr("Il ne devrait pas y avoir de fauteuil dans une cuisine.")


dialogId("kuch-m-kreslo2", "font_small", "Everybody wants to rest sometimes.")
dialogStr("Tout le monde peut se reposer par moment.")


dialogId("kuch-m-stolky", "font_small", "I have seen these tables somewhere.")
dialogStr("J'ai vu ces tables quelque part.")


dialogId("kuch-v-serie", "font_big", "They are mass-produced, you know.")
dialogStr("Elles sont produites en masse, tu sais.")


dialogId("kuch-m-pekne", "font_small", "But they are nice. We should order a few too.")
dialogStr("Mais elles sont pas mal. Commandons en quelques unes, nous aussi.")


dialogId("kuch-v-obavam", "font_big", "I am afraid that only I can get out of this space.")
dialogStr("J'ai peur de simplement sortir de là.")


dialogId("kuch-m-zapeklite", "font_small", "It seems that even this ship contains some demanding problems.")
dialogStr("Il semblerait que même ce navire contienne quelques problèmes captivants.")


dialogId("kuch-v-mec", "font_big", "Why is that sword here?")
dialogStr("Pourquoi est-ce qu'il y a une épée ici ?")


dialogId("kuch-m-porcovani", "font_small", "Maybe they used it to cut the meat.")
dialogStr("Peut-être l'utilisaient-ils pour couper la viande.")


dialogId("kuch-v-nedela", "font_big", "Certainly. But you don`t cut meat with a sword in the kitchen, usually.")
dialogStr("Certainement. Mais on ne coupe pas la viande avec une épée habituellement.")


dialogId("kuch-m-kuchari", "font_small", "We are lucky there are no cooks here. They could try to cook us.")
dialogStr("Nous avons de la chance, il n'y a pas de cuisinier ici. Il aurait pu essayer de nous cuire.")


dialogId("kuch-v-svitek0", "font_big", "There must be some recipe on that parchment.")
dialogStr("Il doit y avoir une recette sur ce parchemin.")


dialogId("kuch-v-svitek1", "font_big", "There must be some culinary mystery on that parchment.")
dialogStr("Il doit y avoir quelque mystère culinaire sur ce parchemin.")


dialogId("kuch-m-recept", "font_small", "Possibly, how to cook the fish.")
dialogStr("Probablement, comment cuire les poissons.")

==> fillets-ng-data_1.0.0.orig.tar.gz: fillets-ng-data-1.0.0/script/kitchen/dialogs_fr.lua <==

dialogId("kuch-m-objev0", "font_small", "Oh my, this is a nice kitchen.")
dialogStr("Hé bien, c'est une chouette cuisine.")


dialogId("kuch-m-objev1", "font_small", "Yeah, we discovered the ship kitchen.")
dialogStr("Ouais, nous avons découvert la cuisine du bateau.")


dialogId("kuch-m-objev2", "font_small", "Darned kitchen.")
dialogStr("Sacrée cuisine.")


dialogId("kuch-m-objev3", "font_small", "And now we are in the captain Silver’s kitchen.")
dialogStr("Et maintenant nous sommes dans la cuisine du capitaine Silver.")


dialogId("kuch-v-varil", "font_big", "I don’t think he was a cook himself.")
dialogStr("Je ne pense pas qu'il cuisinait lui-même.")


dialogId("kuch-v-problem", "font_big", "But this is not our problem.")
dialogStr("Mais ce n'est pas notre problème.")


dialogId("kuch-m-noproblem", "font_small", "There are not many problems here. I can swim out at once.")
dialogStr("Il n'y a pas de problème ici. Je peux nager vers la sortie.")


dialogId("kuch-v-podivej", "font_big", "But just have a look at me.")
dialogStr("Mais regarde-moi un peu.")


dialogId("kuch-v-stolky0", "font_big", "I can’t understand how these serving tables got there.")
dialogStr("Je ne comprends pas comment ces tables sont arrivées là.")


dialogId("kuch-v-stolky1", "font_big", "These tables are in the way.")
dialogStr("Ces tables bloquent le chemin.")


dialogId("kuch-v-stolky2", "font_big", "This little chamber gives me the creeps.")
dialogStr("Cette petite pièce me donne la frousse.")


dialogId("kuch-v-odsud0", "font_big", "I can’t get out of here!")
dialogStr("Je ne peux pas sortir d'ici !")


dialogId("kuch-m-premyslim0", "font_small", "I’m just thinking how to help you.")
dialogStr("Je réfléchis simplement à comment t'aider.")


dialogId("kuch-v-odsud1", "font_big", "Help me somehow!")
dialogStr("Aide-moi à tout prix !")


dialogId("kuch-m-premyslim1", "font_small", "I am thinking...")
dialogStr("Je réfléchis...")


dialogId("kuch-m-premyslim2", "font_small", "I am on my way.")
dialogStr("J'arrive.")


dialogId("kuch-m-hrnec0", "font_small", "Yuck, there is something left in this pot!")
dialogStr("Beurk, il reste quelque chose dans ce pot !")


dialogId("kuch-m-hrnec1", "font_small", "This pot wasn’t even washed up.")
dialogStr("Ce pot n'a jamais été lavé.")


dialogId("kuch-m-hrnec2", "font_small", "Nobody washes the dishes here.")
dialogStr("Personne ne fait la vaisselle ici.")


dialogId("kuch-v-kreslo0", "font_big", "If there was no chair, it would save us a lot of work.")
dialogStr("S'il n'y avait pas de fauteuil, nous aurions beaucoup moins de travail.")


dialogId("kuch-v-ja", "font_big", "Especially myself.")
dialogStr("Surtout moi.")


dialogId("kuch-m-kreslo0", "font_small", "What is a chair doing in a kitchen?")
dialogStr("Que fait un fauteuil dans une cuisine ?")


dialogId("kuch-v-kreslo1", "font_big", "There should be no chairs in the kitchen.")
dialogStr("Il ne devrait pas y avoir de fauteuil dans une cuisine.")


dialogId("kuch-m-kreslo2", "font_small", "Everybody wants to rest sometimes.")
dialogStr("Tout le monde peut se reposer par moment.")


dialogId("kuch-m-stolky", "font_small", "I have seen these tables somewhere.")
dialogStr("J'ai vu ces tables quelque part.")


dialogId("kuch-v-serie", "font_big", "They are mass-produced, you know.")
dialogStr("Elles sont produites en masse, tu sais.")


dialogId("kuch-m-pekne", "font_small", "But they are nice. We should order a few too.")
dialogStr("Mais elles sont pas mal. Commandons en quelques unes, nous aussi.")


dialogId("kuch-v-obavam", "font_big", "I am afraid that only I can get out of this space.")
dialogStr("J'ai peur d'être le seul à pouvoir sortir de là.")


dialogId("kuch-m-zapeklite", "font_small", "It seems that even this ship contains some demanding problems.")
dialogStr("Il semblerait que même ce navire contienne quelques problèmes captivants.")


dialogId("kuch-v-mec", "font_big", "Why is that sword here?")
dialogStr("Que fait cette épée ici ?")


dialogId("kuch-m-porcovani", "font_small", "Maybe they used it to cut the meat.")
dialogStr("Peut-être l'utilisaient-ils pour couper la viande.")


dialogId("kuch-v-nedela", "font_big", "Certainly. But you don’t cut meat with a sword in the kitchen, usually.")
dialogStr("Certainement. Mais on ne coupe pas la viande dans une cuisine avec une épée habituellement.")


dialogId("kuch-m-kuchari", "font_small", "We are lucky there are no cooks here. They could try to cook us.")
dialogStr("Nous avons de la chance, il n'y a pas de cuisiniers ici. Ils auraient pu tenter de nous cuire.")


dialogId("kuch-v-svitek0", "font_big", "There must be some recipe on that parchment.")
dialogStr("Il doit y avoir une recette sur ce parchemin.")


dialogId("kuch-v-svitek1", "font_big", "There must be some culinary mystery on that parchment.")
dialogStr("Il doit y avoir un mystère culinaire sur ce parchemin.")


dialogId("kuch-m-recept", "font_small", "Possibly, how to cook the fish.")
dialogStr("Probablement, comment cuire les poissons.")
